import 'dart:ui';

import 'package:fis_jsonrpc/services/aIDiagnosis.m.dart';

abstract class IURMDataProcessor {
  URMMeasureParams getURMMeasureParams();
  int get fullVisualPixelWidth; // 全图像素宽度
  int get fullVisualPixelHeight; // 全图像素高度
  int get screenWidth; // 视图宽度
  int get screenHeight; // 视图高度
  int get screenX; // 视图X坐标
  int get screenY; // 视图Y坐标
  double get phywidth; // 图像物理宽度

  bool get showLeftRight; // 是否显示左右双幅
  bool get zoomOn; // 是否开启缩放
  Offset get zoomCenterPct; // 缩放在视图中心的百分比坐标
  double get zoomScaleX; // 缩放比例X
  double get zoomScaleY; // 缩放比例Y
}

class URMMeasureParams {
  String remedicalCode = ""; // 手动取值
  String urmImageType = "1"; // 手动取值
  bool urmBlend = false; // 手动取值
  double downsampleIndex = 0; // 手动取值
  double intPowerDen = 0; // 手动取值
  double intPowerDir = 0; // 手动取值
  double sigmaGauss = 0; // 手动取值
  double vessScale = 0; // 手动取值
  double velMaxScaler = 0; // 手动取值
  double velMinScaler = 0; // 手动取值
  double iterations = 0; // 手动取值
  int imgProcessVer = 0; // 手动取值
  bool zoomOn = false; // 手动取值
  double zoomRoix = 0; // 手动取值
  double zoomRoiy = 0; // 手动取值
  double zoomRoiwidth = 0; // 手动取值
  double zoomRoiheight = 0; // 手动取值
  int roix = 0; // 手动取值
  int roiy = 0; // 手动取值
  int roiwidth = 0; // 手动取值
  int roiheight = 0; // 手动取值
  bool leftRight = false; // 手动取值
  bool upDown = false; // 手动取值
  int screenWidth = 0; // 手动取值
  int screenHeight = 0; // 手动取值
  List<UrmPoint>? urmTraceDPoints; // 手动取值
  URMMeasureParams({
    required this.remedicalCode,
    required this.urmImageType,
    required this.urmBlend,
    required this.downsampleIndex,
    required this.intPowerDen,
    required this.intPowerDir,
    required this.sigmaGauss,
    required this.vessScale,
    required this.velMaxScaler,
    required this.velMinScaler,
    required this.iterations,
    required this.imgProcessVer,
    required this.zoomOn,
    required this.zoomRoix,
    required this.zoomRoiy,
    required this.zoomRoiwidth,
    required this.zoomRoiheight,
    required this.roix,
    required this.roiy,
    required this.roiwidth,
    required this.roiheight,
    required this.leftRight,
    required this.upDown,
    required this.screenWidth,
    required this.screenHeight,
    required this.urmTraceDPoints,
  });
}
